Types describing Lazer HTTP and WebSocket APIs.
Structs
- Error
Response - Sent from the server if an internal error occured while serving data for an existing subscription, or a client request sent a bad request.
- Invalid
Feed Subscription Details - Json
Binary Data - Json
Update - Latest
Price Request - Latest
Price Request Repr - Parsed
Feed Payload - Parsed representation of a feed update.
- Parsed
Payload - Price
Request - Price
Request Repr - Reduce
Price Request - Signed
Guardian SetUpgrade - Signed
Merkle Root - Stream
Updated Response - Sent from the server when new data is available for an existing subscription
(only if
delivery_format == Json). - Subscribe
Request - A subscription request.
- Subscribed
Response - Sent from the server when a subscription succeeded and all specified feeds were valid.
- Subscribed
With Invalid Feed IdsIgnored Response - Sent from the server when a subscription succeeded, but some of the specified feeds were invalid.
- Subscription
Error Response - Sent from the server if the requested subscription or unsubscription request could not be fulfilled.
- Subscription
Id - Subscription
Params - Subscription
Params Repr - Unsubscribe
Request - An unsubscription request.
- Unsubscribed
Response - Notification of a successful unsubscription.
Enums
- Channel
- Channel
Schema Repr - Delivery
Format - Format
- Json
Binary Encoding - Market
Session - Trading
Status - WsRequest
- A WebSocket JSON message sent from the client to the server.
- WsResponse
- A WebSocket JSON message sent from the server to the client.