pub struct JsonUpdate {
pub parsed: Option<ParsedPayload>,
pub evm: Option<JsonBinaryData>,
pub solana: Option<JsonBinaryData>,
pub le_ecdsa: Option<JsonBinaryData>,
pub le_unsigned: Option<JsonBinaryData>,
}Fields
parsed: Option<ParsedPayload>Parsed representation of the price update.
Present unless parsed = false is specified in subscription params.
evm: Option<JsonBinaryData>Signed on-chain payload for EVM. Only present if Evm is present in formats in subscription params.
solana: Option<JsonBinaryData>Signed on-chain payload for Solana. Only present if Solana is present in formats in subscription params.
le_ecdsa: Option<JsonBinaryData>Signed binary payload for off-chain verification. Only present if LeEcdsa is present in formats in subscription params.
le_unsigned: Option<JsonBinaryData>Unsigned binary payload. Only present if LeUnsigned is present in formats in subscription params.