ParsedFeedPayload

Struct ParsedFeedPayload 

pub struct ParsedFeedPayload {
Show 14 fields pub price_feed_id: PriceFeedId, pub price: Option<Price>, pub best_bid_price: Option<Price>, pub best_ask_price: Option<Price>, pub publisher_count: Option<u16>, pub exponent: Option<i16>, pub confidence: Option<Price>, pub funding_rate: Option<Rate>, pub funding_timestamp: Option<TimestampUs>, pub funding_rate_interval: Option<DurationUs>, pub market_session: Option<MarketSession>, pub ema_price: Option<Price>, pub ema_confidence: Option<Price>, pub feed_update_timestamp: Option<TimestampUs>,
}
Parsed representation of a feed update.

Fields

price_feed_id: PriceFeedId

Feed ID.

price: Option<Price>

For price feeds: main price. For funding rate feeds: funding price. Only present if the price property was specified in the SubscriptionRequest and the value is currently available for this price feed.

best_bid_price: Option<Price>

Best bid price for this price feed. Only present if the bestBidPrice property was specified in the SubscriptionRequest and this is a price feed and the value is currently available for this price feed.

best_ask_price: Option<Price>

Best ask price for this price feed. Only present if the bestAskPrice property was specified in the SubscriptionRequest and this is a price feed and the value is currently available for this price feed.

publisher_count: Option<u16>

Number of publishers contributing to this feed update. Only present if the publisherCount property was specified in the SubscriptionRequest.

exponent: Option<i16>

Exponent for this feed. Only present if the exponent property was specified in the SubscriptionRequest. Each decimal field provided by the feed (price, fundingRate, etc) returns the mantissa of the value. The actual value can be calculated as mantissa * 10^exponent.

confidence: Option<Price>

Confidence for this price feed. Only present if the confidence property was specified in the SubscriptionRequest and this is a price feed and the value is currently available for this price feed.

funding_rate: Option<Rate>

Perpetual future funding rate for this feed. Only present if the fundingRate property was specified in the SubscriptionRequest and this is a funding rate feed and the value is currently available for this price feed.

funding_timestamp: Option<TimestampUs>

Most recent perpetual future funding rate timestamp for this feed. Only present if the fundingTimestamp property was specified in the SubscriptionRequest and this is a funding rate feed and the value is currently available for this price feed.

funding_rate_interval: Option<DurationUs>

Duration, in microseconds, between consecutive funding rate updates for this price feed. Only present if the fundingRateInterval property was requested in the SubscriptionRequest and this is a funding rate feed and the value is defined for that feed.

market_session: Option<MarketSession>

Market session for this price feed. Only present if the marketSession property was specified in the SubscriptionRequest.

ema_price: Option<Price>

Exponential moving average of the main price for this price feeds. Only present if the emaPrice property was specified in the SubscriptionRequest and this is a price feed and the value is currently available for this price feed.

ema_confidence: Option<Price>

Exponential moving average of the confidence for this price feeds. Only present if the emaConfidence property was specified in the SubscriptionRequest and this is a price feed and the value is currently available for this price feed.

feed_update_timestamp: Option<TimestampUs>

Implementations

Source

impl ParsedFeedPayload

pub fn new( price_feed_id: PriceFeedId, data: &AggregatedPriceFeedData, properties: &[PriceFeedProperty], ) -> Self

pub fn new_full( price_feed_id: PriceFeedId, exponent: Option<i16>, data: &AggregatedPriceFeedData, ) -> Self