pub struct SubscribeRequest {
pub subscription_id: SubscriptionId,
pub params: SubscriptionParams,
}Expand description
A subscription request.
After a successful subscription, the server will respond with a SubscribedResponse
or SubscribedWithInvalidFeedIdsIgnoredResponse message,
followed by StreamUpdatedResponse messages.
If a subscription cannot be made, the server will respond with a SubscriptionError
message containing the error message.
Fields
subscription_id: SubscriptionIdA number chosen by the client to identify the new subscription. This identifier will be sent back in any responses related to this subscription.
params: SubscriptionParamsProperties of the new subscription.