pub struct RpcPrice {
pub conf: u64,
pub expo: i32,
pub price: i64,
pub publish_time: i64,
}Expand description
A price with a degree of uncertainty at a certain time, represented as a price +- a confidence interval.
The confidence interval roughly corresponds to the standard error of a normal distribution.
Both the price and confidence are stored in a fixed-point numeric representation, x * 10^expo, where expo is the exponent. For example:
Fields
conf: u64The confidence interval associated with the price, stored as a string to avoid precision loss
expo: i32The exponent associated with both the price and confidence interval. Multiply those values
by 10^expo to get the real value.
price: i64The price itself, stored as a string to avoid precision loss
publish_time: i64When the price was published. The publish_time is a unix timestamp, i.e., the number of
seconds since the Unix epoch (00:00:00 UTC on 1 Jan 1970).