Module api

Module api 

Types describing Lazer HTTP and WebSocket APIs.

Structs

ErrorResponse
Sent from the server if an internal error occured while serving data for an existing subscription, or a client request sent a bad request.
InvalidFeedSubscriptionDetails
JsonBinaryData
JsonUpdate
LatestPriceRequest
LatestPriceRequestRepr
ParsedFeedPayload
Parsed representation of a feed update.
ParsedPayload
PriceRequest
PriceRequestRepr
ReducePriceRequest
StreamUpdatedResponse
Sent from the server when new data is available for an existing subscription (only if delivery_format == Json).
SubscribeRequest
A subscription request.
SubscribedResponse
Sent from the server when a subscription succeeded and all specified feeds were valid.
SubscribedWithInvalidFeedIdsIgnoredResponse
Sent from the server when a subscription succeeded, but some of the specified feeds were invalid.
SubscriptionErrorResponse
Sent from the server if the requested subscription or unsubscription request could not be fulfilled.
SubscriptionId
SubscriptionParams
SubscriptionParamsRepr
UnsubscribeRequest
An unsubscription request.
UnsubscribedResponse
Notification of a successful unsubscription.

Enums

Channel
ChannelSchemaRepr
DeliveryFormat
Format
JsonBinaryEncoding
MarketSession
TradingStatus
WsRequest
A WebSocket JSON message sent from the client to the server.
WsResponse
A WebSocket JSON message sent from the server to the client.

Functions

default_parsed
schema_default_price_feed_ids
schema_default_symbols

Type Aliases

LatestPriceResponse
PriceResponse
ReducePriceResponse