pub struct SubscriptionParamsRepr {
pub price_feed_ids: Option<Vec<PriceFeedId>>,
pub symbols: Option<Vec<String>>,
pub properties: Vec<PriceFeedProperty>,
pub formats: Vec<Format>,
pub delivery_format: DeliveryFormat,
pub json_binary_encoding: JsonBinaryEncoding,
pub parsed: bool,
pub channel: Channel,
pub ignore_invalid_feeds: bool,
}Fields
price_feed_ids: Option<Vec<PriceFeedId>>List of feed IDs. Either feed ids or symbols must be specified.
symbols: Option<Vec<String>>List of feed symbols. Either feed ids or symbols must be specified.
properties: Vec<PriceFeedProperty>List of feed properties the sender is interested in.
formats: Vec<Format>Requested formats of the payload. As part of each feed update, the server will send on-chain payloads required to validate these price updates on the specified chains.
delivery_format: DeliveryFormatIf json is selected, the server will send price updates as JSON objects
(the on-chain payload will be encoded according to the jsonBinaryEncoding property).
If binary is selected, the server will send price updates as binary messages.
json_binary_encoding: JsonBinaryEncodingFor deliveryFormat == "json", the on-chain payload will be encoded using the specified encoding.
This option has no effect for deliveryFormat == "binary".
parsed: boolIf true, the stream update will contain a parsed JSON field containing
all data of the update.
channel: ChannelChannel determines frequency of updates.
ignore_invalid_feeds: boolIf true, the subscription will ignore invalid feed IDs and subscribe to any valid feeds. Otherwise, the entire subscription will fail if any feed is invalid.